﻿using System;
using System.ServiceModel;
using System.Windows;
using System.Windows.Browser;
using System.Windows.Controls;
using MapApplication.TokenService;
using Telerik.Windows.Controls.Map.VEImageryService;
using Telerik.Windows.Controls.Map;

namespace MapApplication
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            this.Loaded += MainPageLoaded;

            this.RadMap1.InitializeCompleted += this.MapInitializeCompleted;
        }

        private void MapInitializeCompleted(object sender, EventArgs e)
        {
            // We can set map properties when control is initialized.
            this.RadMap1.Center = new Telerik.Windows.Controls.Map.Location(37.684297, -122.06924);
            this.RadMap1.ZoomLevel = 13;
        }

        private void MainPageLoaded(object sender, RoutedEventArgs e)
        {
            // retrieve the token necessary for correct operation of the Virtual Earth map provider.
            this.GetVirtualEarthToken();
        }

        private void GetVirtualEarthToken()
        {
            Uri serviceUri = new Uri(HtmlPage.Document.DocumentUri, "RadMapTokenService.svc");
            EndpointAddress address = new EndpointAddress(serviceUri);

            BasicHttpBinding binding = new BasicHttpBinding()
            {
                MaxBufferSize = int.MaxValue,
                MaxReceivedMessageSize = int.MaxValue
            };

            TokenService.RadMapTokenServiceClient client = new TokenService.RadMapTokenServiceClient(binding, address);

            client.GetTokenCompleted += GetTokenCompleted;

            try
            {
                client.GetTokenAsync();
            }
            catch (Exception ex)
            {
                throw new Exception(string.Format("Token Service Exception: {0}", ex.Message));
            }
        }

        private void GetTokenCompleted(object sender, GetTokenCompletedEventArgs e)
        {
            string token = e.Result;

            // Initialize Virtual Earth map provider.
            VEMapProvider provider = new VEMapProvider(MapMode.Aerial, true, token);
            this.RadMap1.Provider = provider;
        }
    }
}
